package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcProject;

/**
 * cmc项目Mapper接口
 * 
 * @author cmc
 * @date 2024-01-30
 */
public interface CmcProjectMapper 
{
    /**
     * 查询cmc项目
     * 
     * @param projectId cmc项目主键
     * @return cmc项目
     */
    public CmcProject selectCmcProjectByProjectId(String projectId);

    /**
     * 查询cmc项目
     *
     * @param projectNumber cmc项目编号
     * @return cmc项目
     */
    public CmcProject selectCmcProjectByProjectNumber(String projectNumber);

    /**
     * 获取项目负责人负责的项目详细信息
     *
     * @param projectLeader cmc项目负责人
     * @return cmc项目集合
     */
    public List<CmcProject> selectCmcProjectListByProjectLeader(String projectLeader);

    /**
     * 查询cmc项目列表
     * 
     * @param cmcProject cmc项目
     * @return cmc项目集合
     */
    public List<CmcProject> selectCmcProjectList(CmcProject cmcProject);

    /**
     * 新增cmc项目
     * 
     * @param cmcProject cmc项目
     * @return 结果
     */
    public int insertCmcProject(CmcProject cmcProject);

    /**
     * 修改cmc项目
     * 
     * @param cmcProject cmc项目
     * @return 结果
     */
    public int updateCmcProject(CmcProject cmcProject);

    /**
     * 删除cmc项目
     * 
     * @param projectId cmc项目主键
     * @return 结果
     */
    public int deleteCmcProjectByProjectId(String projectId);

    /**
     * 批量删除cmc项目
     * 
     * @param projectIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcProjectByProjectIds(String[] projectIds);
}
